@@ -10,7 +10,7 @@ PDL::Func - interpolation, integration, & gradient estimation (differentiation)
  use PDL::Math;
 
  # somewhat pointless way to estimate cos and sin,
- # but is shows that you can thread if you want to
+ # but is shows that you can broadcast if you want to
  # (and the library lets you)
  #
  my $obj = PDL::Func->init( Interpolate => "Hermite" );
@@ -374,7 +374,7 @@ sub _init_hermite {
     my ( $x, $y, $bc ) = $self->_get_value( qw( x y bc ) );
 
     # check 1st dimention of x and y are the same
-    #  ie allow the possibility of threading
+    #  ie allow the possibility of broadcasting
     my $xdim = $x->getdim( 0 );
     my $ydim = $y->getdim( 0 );
     croak "ERROR: x and y ndarrays must have the same first dimension.\n"
@@ -738,7 +738,13 @@ sub _interp_hermite {
     # get gradient
     my $g = $self->_get_value( 'g' );
 
-    my ( $yi, $ierr ) = chfe( $x, $y, $g, 0, $xi );
+    my @highest_dims;
+    for my $param ($x,$y,$g,$xi) {
+      my @this_dims = $param->dims;
+      @highest_dims = @this_dims if @this_dims > @highest_dims;
+    }
+    shift @highest_dims; # don't care about bottom one
+    my ( $yi, $ierr ) = chfe( $x, $y, $g, PDL->ones(PDL::long(),@highest_dims), $xi );
     $self->{flags}{routine} = "chfe";
     $self->_set_value( err => $ierr );
 
